************************************************************************
*                                                                      *
      subroutine dsdarc(icc,icm,incp,
     &                  pnrg,atarg,angle,sigs,dsigs,escat,etarg,angcm)
*                                                                      *
*        compute elastic scattering cross-section using                *
*        Fraunhoffer diffraction (b) for scattering formulae,          *
*        see S. Pearlstein, Nuc. Sci. Eng., 49, p.162-171(1972)        *
*                                                                      *
*        Hutcheon PRL 47,315(81) data 200-400 mev p+pb data            *
*                                                                      *
*     input:                                                           *
*        icc      : 0 -> Pearlstein                                    *
*                 : 1 -> Pearlstein + Hutcheon                         *
*                 : 2 -> Niita                                         *
*        icm      : 0 -> cm, 1 -> lab  input and output                *
*        incp     : 1->proton, 2->neutron                              *
*        pnrg     : kinetic energy of incident nucleon in lab (MeV)    *
*        atarg    : target mass number                                 *
*        angle    : scattering angle (deg) cm or lab                   *
*        sigs     : non-elastic scattering cross-section (b)           *
*                                                                      *
*     output:                                                          *
*        dsigs    : differential elastic cross-section (b/sr)          *
*        escat    : lab kinetic energy of scattered nucleon (MeV)      *
*        etarg    : =pnrg-escat, lab k.e. of scattered target (MeV)    *
*        angcm    : cm scattering angle (deg)                          *
*                                                                      *
************************************************************************

      implicit real*8(a-h,o-z)

*-----------------------------------------------------------------------
*     constants
*-----------------------------------------------------------------------

            rz = 0.14
            pi = 3.1415927

*-----------------------------------------------------------------------
*     transformation lab to cm
*-----------------------------------------------------------------------

            call syscrc(icm,incp,pnrg,atarg,angle,vk,angzlm,escat,conv)

            angcm = angzlm
            etarg = pnrg - escat

            a  = atarg
            ia = nint( a )

*-----------------------------------------------------------------------
*        original elastic cross section
*-----------------------------------------------------------------------

         if( icc .ne. 2 ) then

            r = ( rz * a**0.3333
     &          + 0.122 * ( a + 1.0 ) / a ) * 1.d-12

            del = 0.05 * r

            area = pi * r * r * 1.d+24
            vkr2 = 2.0 * vk * r

            call bessel(0,vkr2,besz)
            call bessel(1,vkr2,bes1)

            sig = area * ( 1.0 - besz**2 - bes1**2 )

*-----------------------------------------------------------------------
*        new parametrization by K. Niita
*-----------------------------------------------------------------------

         else

            r = ( sqrt( sigs * 100. ) / pi + 0.0 ) * 1.d-13

            r = r * ( -43.78 / ( a + 136.6 ) + 2.23 )

            r = r * ( 1.0 
     &            + ( ( 0.8 + 0.2 * exp( -( a / 100.0 )**4 ) ) - 1.0 )
     &            *  exp( - ( pnrg / 40.0 )**2 ) )

            del = 0.45 * 1.d-13

            rfac = 0.66 * exp( -( 541.4 / pnrg )**2 )
            dfac = 1.80 * exp( -( 61.43 / a )**2 )

            r = r * ( 1.0 + rfac )

            del = del * ( 1.0 + dfac * rfac * 1.35 )

         end if

*-----------------------------------------------------------------------
*     differential cross section
*-----------------------------------------------------------------------

            y0 = ( vk * r * r )**2 * 1.d+24

c           u = cosd(angzlm)
c------------------------------------------------------------------------
c     line above was replaced by the one below by M. Herman to avoid 
c     non-standard cosine function using argument expressed in degrees
c------------------------------------------------------------------------
            u = cos(angzlm * 3.14159 / 180.0)
            s = sqrt( ( 1.0 - u ) / 2.0 )

            if( u .eq. 1.0 ) s = 0.0

            xav = 2.0 * vk * r * s

         if( xav .le. 1.d-2 ) then

            xj1x = 0.5
            y1   = xj1x * xj1x
            y2   = 1.0

         else

            xpl = 2.0 * vk * ( r + del ) * s
            xmi = 2.0 * vk * ( r - del ) * s

            call bessel(1,xpl,xj1pl)
            call bessel(1,xmi,xj1mi)

            if( icc .ne. 2 ) then

               fp1 = 1.0
               fp2 = 1.0

            else

               fp1 = 1.4
               fp2 = 2.0 - fp1

            end if

            y1 = 0.5 * ( 
     &           fp1 * ( xj1pl / xpl )**2 + 
     &           fp2 * ( xj1mi / xmi )**2 )

*-----------------------------------------------------------------------
*           following fits Hutcheon PRL 47,315(81)
*           data 200-400 mev p+pb data
*           icc = 0 -> Pearlstein
*                 1 -> Pearlstein + Hutcheon
*                 2 -> Niita
*-----------------------------------------------------------------------

            if( icc .eq. 0 ) then

               fac0 = 1.0

               y2 = fac0

            else if( icc .eq. 1 ) then

               cf1  = 0.2 * ( 208. / a )**0.3333
               fac1 = exp( - cf1 * xav - cf1 / 40. * xav**2 )

               y2 = fac1

            else if( icc .eq. 2 ) then

               cf2 = 0.1 * ( 100. / a )**0.3333
               facc = exp( - cf2 * xav - cf2 / 40. * xav**2 )

               emas = ( -14512.0 / ( a + 103.5 ) + 146.7 )
               fac2 = 1.0 + ( facc - 1.0 ) 
     &              * ( 1.0 - exp( - ( pnrg / emas )**4 ) )

               cf3 = 2.5 * ( 80. / a )**0.3333
               angc = 160.0 * 50.0 / ( pnrg + 50.0 ) + 20.0

               angd = - 15.0 / 190.0 * a + 20.79
               ange =   15.0 / 190.0 * a + 49.2

              angc = ( 180.0 - angd ) * ange / ( pnrg + ange ) + angd

               faca = exp( - cf3 * ( angzlm / angc )**2 )

               fac3 = 1.0 + ( faca - 1.0 ) 
     &              * ( 1.0 - exp( - ( pnrg / 60.0 )**2 ) )

               y2 = fac2 * fac3

            end if


         end if

*-----------------------------------------------------------------------

            dsigs = conv * y0 * y1 * y2

            if( abs(dsigs) .le. 1.d-12 ) dsigs = 0.0


*-----------------------------------------------------------------------

      return
      end
